from stretch_body.end_of_arm_tools import EOA_Wrist_DW3_Tool_NIL


class EOA_Wrist_DW3_Tool_Tablet_12in(EOA_Wrist_DW3_Tool_NIL):
    def __init__(self, name='eoa_wrist_dw3_tool_tablet_12in'):
        EOA_Wrist_DW3_Tool_NIL.__init__(self, name)

